@@ -21,7 +21,7 @@ use base 'Apache2::WebApp::Plugin';
 use Apache2::Cookie;
 use Params::Validate qw( :all );
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~[  OBJECT METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
@@ -171,6 +171,13 @@ Use of CPAN.pm in interactive mode:
 Just like the manual installation of Perl modules, the user may need root access during
 this process to insure write permission is allowed within the installation directory.
 
+=head1 CONFIGURATION
+
+In order to set a browser cookie, you need to specify a valid hostname in your I<webapp.conf>
+
+  [apache]
+  domain = www.domain.com
+
 =head1 OBJECT METHODS
 
 =head2 set
@@ -181,7 +188,6 @@ Set a new browser cookie.
         name    => 'foo',
         value   => 'bar',
         expires => '24h',
-        domain  => '.domain.com',
         secure  => 0,
     });
 
